- dict
A vector of terms, list of such vectors, or a matrix-like object to be
categorized by read.dic.
- text
A vector of text to extract matches from. If not specified, will use the terms
in the term_map retrieved from select.lspace.
- space
A vector space used to calculate similarities between term matches.
Name of a the space (see select.lspace), a matrix with terms as row names, or
TRUE to auto-select a space based on matched terms.
- glob
Logical; if TRUE, converts globs (asterisk wildcards) to regular expressions.
If not specified, this will be set automatically.
- parse_phrases
Logical; if TRUE (default) and space is specified, will
break unmatched phrases into single terms, and average across and matched vectors.
- tolower
Logical; if FALSE, will retain text's case.
- punct
Logical; if FALSE, will remove punctuation markings in text.
- special
Logical; if FALSE, will attempt to replace special characters in text.
- as_terms
Logical; if TRUE, will treat text as terms, meaning dict
terms will only count as matches when matching the complete text.
- bysentence
Logical; if TRUE, will split text into sentences, and only
consider unique sentences.
- as_string
Logical; if FALSE, returns matches as tables rather than a string.
- term_map_freq
Proportion of terms to include when using the term map as a source
of terms. Applies when text is not specified.
- term_map_spaces
Number of spaces in which a term has to appear to be included.
Applies when text is not specified.
- outFile
File path to write results to, always ending in .csv.
- space_dir
Directory from which space should be loaded.
- verbose
Logical; if FALSE, will not display status messages.